@@ -42,7 +42,7 @@
 
 int rigol_dsa_screenshot(char *address, char *id, int timeout)
 {
-    char response[IMAGE_SIZE_MAX];
+    char* response = malloc(IMAGE_SIZE_MAX);
     char *command, *image;
     int device, length, n;
     char c;
@@ -54,7 +54,7 @@ int rigol_dsa_screenshot(char *address, char *id, int timeout)
     if (device == LXI_ERROR)
     {
         error_printf("Failed to connect\n");
-        return 1;
+        goto error_connect;
     }
 
     // Send SCPI command to grab BMP image
@@ -64,7 +64,7 @@ int rigol_dsa_screenshot(char *address, char *id, int timeout)
     if (length < 0)
     {
         error_printf("Failed to receive message\n");
-        return 1;
+        goto error_receive;
     }
 
     // Strip TMC block header
@@ -77,10 +77,21 @@ int rigol_dsa_screenshot(char *address, char *id, int timeout)
     // Dump remaining BMP image data to file
     screenshot_file_dump(image, length, "bmp");
 
+    // Free allocated memory for screenshot
+    free(response);
+    
     // Disconnect
     lxi_disconnect(device);
 
     return 0;
+
+error_connect:
+error_receive:
+
+    // Free allocated memory for screenshot
+    free(response);
+
+    return 1;
 }
 
 // Screenshot plugin configuration
