@@ -42,14 +42,14 @@
 
 int rs_hmo_rtb_screenshot(char *address, char *id, int timeout)
 {
-    char *response, *command, *image;
+    char *command, *image;
     int device, length, n;
     char c;
 
     UNUSED(id);
 
     // Prepare response buffer
-    response = malloc(IMAGE_SIZE_MAX);
+    char* response = malloc(IMAGE_SIZE_MAX);
     if (response == NULL)
     {
         error_printf("Failed to allocate response buffer\n");
@@ -61,7 +61,7 @@ int rs_hmo_rtb_screenshot(char *address, char *id, int timeout)
     if (device == LXI_ERROR)
     {
         error_printf("Failed to connect\n");
-        return 1;
+        goto error_connect;
     }
 
     // Send SCPI commands to grab image
@@ -73,7 +73,7 @@ int rs_hmo_rtb_screenshot(char *address, char *id, int timeout)
     if (length < 0)
     {
         error_printf("Failed to receive message\n");
-        return 1;
+        goto error_receive;
     }
 
     // Strip header
@@ -86,10 +86,21 @@ int rs_hmo_rtb_screenshot(char *address, char *id, int timeout)
     // Dump remaining image data to file
     screenshot_file_dump(image, length, "png");
 
+    // Free allocated memory for screenshot
+    free(response);
+    
     // Disconnect
     lxi_disconnect(device);
 
     return 0;
+
+error_connect:
+error_receive:
+
+    // Free allocated memory for screenshot
+    free(response);
+
+    return 1;
 }
 
 
